@@ -23,7 +23,7 @@ class App:
         self.state = {}
         self.scripts = []
         self.styles = []
-        self.vue_use = []
+        self.vue_use = ['vuetify', 'router', 'vtk']
         self.serve = {}
 
         # properties
@@ -88,7 +88,7 @@ class App:
 
     @property
     def favicon(self):
-        return self._layout
+        return self._favicon
 
     @favicon.setter
     def favicon(self, value):
